Monty Python's Flying Circus: Just the Words - Episode 26

# Episode Twenty-six

The Queen will be watching
Coal mine (historical argument)
The man who says things in a very roundabout way
The man who speaks only the ends of words
The man who speaks only the beginnings of words
The man who speaks only the middles of words
Commercials
How to feed a goldfish
The man who collects birdwatcher's eggs
Insurance sketch
Hospital run by RSM
Mountaineer
Exploding version of 'The Blue Danube'
Girls' boarding school
Submarine
Lifeboat (cannibalism)
Undertaker's sketch

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Announcer standing in front of his desk.
Announcer | Ladies and gentlemen, I am not simply going to say 'and now for something completely different' this week, as I do not think it fit. This is a particularly auspicious occasion for us this evening, as we have been told that Her Majesty the Queen will be watching part of the show tonight. We don't know exactly when Her Majesty will be tuning in. We understand that at the moment she is watching 'The Virginian', but we have been promised that we will be informed the moment that she changes channel. Her majesty would like everyone to behave quite normally but her equerry has asked me to request all of you at home to stand when the great moment arrives, although we here in the studio will be carrying on with our humorous vignettes and spoofs in the ordinary way. Thank you. And now without any more ado and completely as normal, here are the opening titles. (bows)
| Very regal animated opening titles.
| CAPTION: 'ROYAL EPISODE THIRTEEN' CAPTION: 'FIRST SPOOF' CAPTION: 'A COAL MINE IN LLANDDAROG CARMARTHEN'
| A nice photograph of a typical pit head. Music over this: 'All Through the Night' being sung in Welsh.
Voice Over | The coal miners of Wales have long been famed for their tough rugged life hewing the black gold from the uncompromising hell of one mile under. This is (at this moment across the bottom of the screen comes the following message in urgent teleprinter style, moving right to left, superimposed 'HM THE QUEEN STILL WATCHING 'THE VIRGINIAN') the story of such men, battling gallantly against floods, roof falls, the English criminal law, the hidden killer carbon monoxide and the ever-present threat of pneumoconiosis which is... a disease miners get.
| Cut to coal face below ground where some miners are engaged at their work. They hew away for a bit, grunting and talking amongst themselves. Suddenly two of them square up to one another.
First Miner | Don't you talk to me like that, you lying bastard.
| He hits the second miner and a fight starts.
Second Miner | You bleeding pig. You're not fit to be down a mine.
First Miner | Typical bleeding Rhondda, isn't it. You think you're so bloody clever.
| They writhe around on the floor pummelling each other. The foreman comes in.
Foreman | You bloody fighting again. Break it up or I'll put this pick through your head. Now what's it all about?
First Miner | He started it.
Second Miner | Oh, you bleeding pig, you started it.
Foreman | I don't care who bloody started it. What's it about?
Second Miner | Well ... he said the bloody Treaty of Utrecht was 1713.
First Miner | So it bloody is.
Second Miner | No it bloody isn't. It wasn't ratified 'til February 1714.
First Miner | He's bluffing. You're mind's gone, Jenkins. You're rubbish.
Foreman | He's right, Jenkins. It was ratified September 1713. The whole bloody pit knows that. Look in Trevelyan, page 468.
Third Miner | He's thinking of the Treaty of bloody Westphalia.
Second Miner | Are you saying I don't know the difference between the War of the bloody Spanish Succession and the Thirty bloody Years War?
Third Miner | You don't know the difference between the Battle of Borodino and a tiger's bum.
| They start to fight.
Foreman | Break it up, break it up. (he hits them with his pickaxe) I'm sick of all this bloody fighting. If it's not the bloody Treaty of Utrecht it's the bloody binomial theorem. This isn't the senior common room at All Souls, it's the bloody coal face.
| A fourth miner runs up.
Fourth Miner (Ian Davidson) | Hey, gaffer, can you settle something? Morgan here says you find the abacus between the triglyphs in the frieze section of the entablature of classical Greek Doric temples.
Foreman | You bloody fool, Morgan, that's the metope. The abacus is between the architrave and the aechinus in the capital.
Morgan | You stinking liar.
| Another fight breaks out. A management man arrives carried in sedan chair by two black flunkies. He wears a colonial governor's helmet and a large sign reading 'frightfully important'. All the miners prostrate themselves on the floor.
Foreman | Oh, most magnificent and merciful majesty, master of the universe, protector of the meek, whose nose we are not worthy to pick and whose very feces are an untrammelled delight, and whose peacocks keep us awake all hours of the night with their noisy lovemaking, we beseech thee, tell thy humble servants the name of the section between the triglyphs in the frieze section of a classical Doric entablature.
Management Man | No idea. Sorry.
Foreman | Right. Everybody out.
| They all walk off throwing down tools. Cut to a newsreader's desk.
Newsreader | Still no settlement in the coal mine dispute at Llanddarog. Miners refused to return to work until the management define a metope. Meanwhile, at Dagenham the unofficial strike committee at Fords have increased their demands to thirteen reasons why Henry III was a bad king. And finally, in the disgusting objects international at Wembley tonight, England beat Spain by a plate of braised pus to a putrid heron. And now, the Toad Elevating Moment.
| CAPTION: 'THE TOAD ELEVATING MOMENT'
| Pompous music. Mix to spinning globe and then to two men in a studio.
Interviewer | Good evening. Well, we have in the studio tonight a man who says things in a very roundabout way. Isn't that so, Mr Pudifoot.
Mr Pudifoot | Yes.
Interviewer | Have you always said things in a very roundabout way?
Mr Pudifoot | Yes.
Interviewer | Well, I can't help noticing that, for someone who claims to say things in a very roundabout way, your last two answers have very little of the discursive quality about them.
Mr Pudifoot | Oh, well, I'm not very talkative today. It's a form of defensive response to intensive interrogative stimuli. I used to get it badly when I was a boy ... well, I say very badly, in fact, do you remember when there was that fashion for, you know, little poodles with small coats...
Interviewer | Ah, now you're beginning to talk in a roundabout way.
Mr Pudifoot | Oh, I'm sorry.
Interviewer | No, no, no, no. Please do carry on ... because that is in fact why we wanted you on the show.
Mr Pudifoot | I thought it was because you were interested in me as a human being. (gets up and leaves)
Interviewer | Well... lets move on to our guest who not only lives in Essex but also speaks only the ends of words. Mr Ohn Ith. Mr Ith, good evening.
| Enter from back of set as per Eamonn Andrews show Mr Ohn Ith. He sits at the desk
Mr Ith | ... ood ... ing.
Interviewer | Nice to have you on the show.
Mr Ith | ... ice ... o ... e ... ere.
Interviewer | Mr Ith, don't you find it very difficult to make yourself understood?
Mr Ith | Yes, it is extremely difficult.
Interviewer | Just a minute, you're a fraud
Mr Ith | Oh no. I can speak the third and fourth sentences perfectly normally.
Interviewer | Oh I see. So your next sentence will be only the ends of words again?
Mr Ith | T's... ight.
Interviewer | Well, let's move on to our next guest who speaks only the beginnings of words, Mr J ... Sm... Mr Sm... good evening.
| Enter Mr Sm.
Mr Sm | G... e...
Interviewer | Well, have you two met before?
Mr Sm | N...
Mr Ith | ... o
Mr Sm | N...
Mr Ith | ... o
Interviewer | Well, this is really a fascinating occasion because we have in the studio Mr ... oh ... I ... who speaks only the middles of words. Good evening.
| Enter Scot.
Scot | .... oo ...... ni...
Interviewer | Um, where do you come from?
Scot | . .. u... i... a...
Interviewer | Dunfermline in Scotland. Well let me introduce you, Mr Ohn Ith...
Mr Ith | ... ood ... ing.
Scot | ... oo ...... ni...
Interviewer | J... Sm...
Scot | ... oo ...... ni...
Mr Sm | G... Eve...
Interviewer | Yes, well, ha, ha, just a moment. Perhaps you would all like to say good evening together.
Mr Sm | G...
Scot | . .. oo...
Mr Ith | ... d
Mr Sm | Eve...
Scot | ... ni...
Mr Ith | ... ing.
| ANIMATION: a sketch advertising Crelm Toothpaste. Cut to a soap powder commercial. Slick adman against neutral background. On his left is an ordinary kitchen table. On his right is a pile of sheets on a stand.
Adman | This table has been treated with ordinary soap powder, but these have been treated with new Fibro-Val. (cut to top shot of interior of washing machine with water spinning round as per ads) We put both of them through our washing machine, and just look at the difference. (cut back to the original set-up; the sheets are obviously painted white; the table is smashed up) The table is broken and smashed, but the sheets, with Fibro-Val, are sparkling clean and white.
| Traditional expanding square links to next commercial. Animated countryside with flowers, butterflies and Babycham animal. A boy and a girl (real, superimposed) wander through hand in hand.
Man's Voice | I love the surgical garment. Enjoy the delights of the Victor Mature abdominal corset. Sail down the Nile on the Bleed-it Kosher Truss. (the adman comes into view over the background; he holds a tailor's dummy - pelvis only - with a truss) And don't forget the Hercules Hold-'em-in, the all.purpose concrete truss for the man with the family hernia.
| He throws away the truss. The background changes to blow-up of a fish tank. The adman is sitting at a desk. He pulls a goldfish bowl over.
Adman | Well last week on Fish Club we learnt how to sex a pike ... and this week we're going to learn how to feed a goldfish. Now contrary to what most people think the goldfish has a ravenous appetite. If it doesn't get enough protein it gets very thin and its bones begin to stick out and its fins start to fall off. So once a week give your goldfish a really good meal. Here's one specially recommended by the board of Irresponsible People. First, some cold consommé or a gazpacho (pours it in), then some sausages with spring greens, sautée potatoes and bread and gravy.
| He tips all this into the bowl. An RSPCA man rushes in, grabs the man and hauls him off.
RSPCA Man | All right, come on, that's enough, that's enough.
Adman | ... treacle tart ... chocolate cake and ...
Voice Over | (and CAPTION:) 'THE RSPCA WISH IT TO BE KNOWN THAT THAT MAN WAS NOT A BONA FIDE ANIMAL LOVER, AND ALSO THAT GOLDFISH DO NOT EAT SAUSAGES. (the man still shouting) SHUT UP! ... THEY ARE QUITE HAPPY WITH BREADCRUMBS, ANT'S EGGS AND THE OCCASIONAL PHEASANT ...'
| The last four words are crossed out in the caption.
Voice Over | Who wrote that?
| Mix to a lyrical shot of wild flowers in beautiful English countryside. Gentle pastoral music. The camera begins to pan away from the flowers, moving slowly across this idyllic scene. Mix in the sound of lovers - the indistinct deep voice, followed by a playful giggle from the girl. At first very distant, but as we continue to pan it increases in volume, until we come to rest on the source of the noise - a tape recorder in front of a bush. After a short paase, the camera tracks round behind this bush where are a couple sitting reading a book each. Pan away from them across afield. In the middle of the pan we come across a smooth, moustachioed little Italian head waiter, in tails etc. We do not stop on him.
Waiter | (bowing to camera) I hope you're enjoying the show.
| The camera pans to the end of the field where we pick up a man in a long mac crawling on all fours through the undergrowth. We follow him as he occasionaly dodges behind a bush or a tree. He is stealthily tracking something. After a few moments he comes up behind a birdwatcher (in deerstalker and tweeds) who lies at the top of a small rise, with his binoculars trained. With infinite caution the man in the long mac slides up behind the birdwatcher, then he stretches out a hand and opens the flap of the birdwatcher's knapsack. He pulls out a small white paper bag. Holding his breath, he feels inside the bag and produces a small pie, then a tomato and finally two hard-boiled eggs. He pockets the hard-boiled eggs, puts the rest back and creeps away.
Voice Over | Herbert Mental collects birdwatchers' eggs. At his home in Surrey he has a collection of over four hundred of them.
| Cut to mantle in a study lined with shelves full of hard-boiled eggs. They all have little labels on the front of them. He goes up and selects one from a long line of identical hard-boiled eggs.
Herbert | 'Ere now. This is a very interesting one. This is from a Mr P. F. Bradshaw. He is usually found in Surrey hedgerows, but I found this one in the gents at St Pancras, uneaten. (he provides the next question himself in bad ventriloquist style) Mr Mental, why did you start collecting birdwatchers' eggs? (normal voice) Oh, well, I did it to get on 'Man Alive'. (ventriloquially) 'Man Alive'? (normal voice) That's right, yes. But then that got all serious, so I carried on in the hope of a quick appearance as an eccentric on the regional section of 'Nationwide'. (ventriloquially) Mr Mental, I believe a couple of years ago you started to collect butterfly hunters. (normal voice) Butterfly hunters? (ventriloquially) Yes. (normal voice) Oh, that's right. Here's a couple of them over here. (he moves to his left; on the wall behind him are the splayed-out figures of two butterfly hunters, with pins through their backs and their names on cards underneath) Nice little chaps. But the hobby I enjoyed most was racing pigeon fanciers.
| An open field. A large hamper, with an attendant in a brown coat standing behind it. The attendant opens the hamper and three pigeon fanciers, (in very fast motion) leap out and run off across the field, wheeling in a curve as birds do. Cut to a series of speeded-up close ups of baskets being opened and pigeon fanciers leaping out. After four or five of these fast close ups cut to long shot of the mass of pigeon fanciers wheeling accross the field like a flock of pigeons. Cut to film of Trafalgar Square. The pigeon fanciers are now running around in the square, wheeling in groups. Cut to Gilliam picture of Trafalgar Square. The chicken man from the opening credits flies past towing a banner which says 'This Space Available, tel 498 5116'. The head of a huge hedgehog - Spiny Norman - appears above St Martin's-in-the-Fields.
Spiny Norman | Dinsdale! Dinsdale!
| Animated sequence then leads to:
| EXTREMELY ANIMATED CAPTION: 'MONTY PYTHON PROUDLY PRESENTS THE INSURANCE SKETCH'
| Interior smooth-looking office. Mr Feldman behind a desk, Mr Martin in front of it. Both point to a sign on the desk: 'Life Insurance Ltd'.
Martin | Good morning. I've been in touch with you about the, er, life insurance...
Feldman | Ah yes, did you bring the um ... the specimen of your um ... and so on, and so on?
Martin | Yes I did. It's in the car. There's rather a lot.
Feldman | Good, good.
Martin | Do you really need twelve gallons?
Feldman | No, no, not really.
Martin | Do you test it?
Feldman | No.
Martin | Well, why do you want it?
Feldman | Well, we do it to make sure that you're serious about wanting insurance, I mean, if you're not, you won't spend a couple of months filling up that enormous churn with mmm, so on and so on...
Martin | Shall I bring it in?
Feldman | Good Lord no. Throw it away.
Martin | Throw it away? I was months filling that thing up.
| The sound of the National Anthem starts. They stand to attention. Martin and Feldman mutter to each other, and we hear a reverential voice over.
Voice Over | And we've just heard that Her Majesty the Queen has just tuned into this programme and so she is now watching this royal sketch here in this royal set. The actor on the left is wearing the great grey suit of the BBC wardrobe department and the other actor is ... about to deliver the first great royal joke here this royal evening. (the camera pans, Martin following it part way, to show the camera crew and the audience, all standing to attention) Over to the fight you can see the royal cameraman, and behind... Oh, we've just heard she's switched over. She's watching the 'News at Ten'.
| Cries of disappointment. Cut to Reggie Bosanquet (the real one) at the 'News at Ten' set. He is reading.
Reggie | ... despite the union's recommendation that the strikers should accept the second and third clauses of the agreement arrived at last Thursday. (the National Anthem starts to play in the background and Reggie stands, continuing to read) Today saw the publication of the McGuffie Commission's controversial report on treatment of in-patients in north London hospitals.
| A hospital: a sign above door says 'Intensive Care Unit'. A group of heavily bandaged patients with crutches, legs and arms in plaster, etc., struggle out and onto a courtyard.
First Doctor | Get on parade! Come on! We haven't got all day, have we? Come on, come on, come on. (the patients painfully get themselves into line) Hurry up ... right! Now, I know some hospitals where you get the patients lying around in bed. Sleeping, resting, recuperating, convalescing. Well, that's not the way we do things here, right! No, you won't be loafing about in bed wasting the doctors' time. You - you horrible little cripple. What's the matter with you?
Patient | Fractured tibia, sergeant.
First Doctor | 'Fractured tibia, sergeant'? 'Fractured tibia, sergeant'? Ooh. Proper little mummy's boy, aren't we? Well, I'll tell you something, my fine friend, if you fracture a tibia here you keep quiet about it! Look at him! (looks more closely) He's broken both his arms and he don't go shouting about it, do he? No! 'Cos he's a man - he's a woman, you see, so don't come that broken tibia talk with me. Get on at the double. One, two, three, pick that crutch up, pick that crutch right up.
| The patient hobbles off at the double and falls over.
Patient | Aaargh!
First Doctor | Right, squad, 'shun! Squad, right turn. Squad, by the left, quick limp! Come on, pick 'em up. Get some air in those wounds.
| Cut to second doctor. He is smoking a cigar.
Second Doctor | (to camera) Here at St Pooves, we believe in ART - Active Recuperation Techniques. We try to help the patient understand that however ill he may be, he can still fulfill a useful role in society. Sun lounge please, Mr Griffiths.
| Pull back to show doctor sitting in a wheelchair. A bandaged patient wheels him off.
Patient | I've got a triple fracture of the right leg, dislocated collar bone and multiple head injuries, so I do most of the heavy work, like helping the surgeon.
Interviewer's Voice | What does that involve?
Patient | Well, at the moment we're building him a holiday home.
Interviewer's Voice | What about the nurses?
Patient | Well, I don't know about them. They're not allowed to mix with the patients.
Interviewer's Voice | Do all the patients work?
Patient | No, no, the ones that are really ill do sport.
| Cut to bandaged patients on a cross-country run.
Voice Over | Yes, one thing patients here dread are the runs.
| The patients climb over a fence with much difficulty. One falls.
Interviewer's Voice | How are you feeling?
Patient | Much better.
| Shots of patients doing sporting acivities.
Voice Over | But patients are allowed visiting. And this week they're visiting an iron foundry at Swindon, which is crying out for unskilled labour. ('Dr Kildare' theme music; shot - doctors being manicured having shoes cleaned etc. by patients) But this isn't the only hospital where doctors' conditions are improving.
| Sign on wall: 'St Nathan's Hospital For Young, Attractive Girls Who Aren't Particularly Ill'. Pan down to a doctor.
Third Doctor | Er, very little shortage of doctors here. We have over forty doctors per bed - er, patient. Oh, be honest. Bed.
| Sign: 'St Gandalf's Hospital For Very Rich People Who Like Giving Doctors Lots Of Money'. Pull back to show another doctor.
Fourth Doctor | We've every facility here for dealing with people who are rich. We can deal with a blocked purse, we can drain private accounts and in the worst cases we can perform a total cashectomy, which is total removal of all moneys from the patient.
| Sign: 'St Michael's Hospital For Linkmen'. Pan down to doctor.
Fifth Doctor | Well, here we try to help people who have to link sketches together. We try to stop them saying 'Have you ever wondered what it would be like if' and instead say something like um... er... 'And now the mountaineering sketch'.
| Cut to a mountaineer hanging on ropes on steep mountain face.
Mountaineer | I haven't written a mountaineering sketch.
| SUPERIMPOSED CAPTION: 'LINK'
Mountaineer | But now over to the exploding version of the 'Blue Danube'.
| Cut to an orchestra in a field playing the 'Blue Danube'. On each musical phrase, a member of the orchestra explodes. Fade to pitch darkness.
Voice Over | And now a dormitory in a girls' public school.
| Noise of female snores. Sound of a window sash being lifted and scrabbling sounds. Padding feet across the dorm.
First Butch Voice | Hello, Agnes... Agnes are you awake? Agnes....
| Sound of waking up. More padding feet.
First Butch Voice | Agnes...
Second Butch Voice | Who is it ... is that you, Charlie?
First Butch Voice | Yeah... Agnes, where's Jane?
Third Butch Voice | I'm over here, Charlie.
First Butch Voice | Jane, we're going down to raid the tuck shop.
Second Butch Voice | Oh good oh ... count me in, girls.
Fourth Butch Voice | Can I come, too, Agnes?
First Butch Voice | Yeah, Joyce.
Fifth Butch Voice | And me and Avril...
Third Butch Voice | Yeah, rather... and Suki.
Fourth Butch Voice | Oh, whacko the diddle-oh.
First Butch Voice | Cave girls... Here comes Miss Rodgers...
| Light goes on to reveal a girls' dorm. In the middle of the floor between the beds are two panto geese which run off immediately the light goes on. There is one man in a string vest and short dibley haircut, chest wig, schoolgirl's skirt, white socks and schoolgirl's shoes. Hanging from the middle of the ceiling is a goat with light bulbs hanging from each foot. In the beds are other batch blokes in string vests... and short hair. At the door stands a commando-type Miss Rodgers.
Miss Rodgers | All right girls, now stop this tomfoolery and get back to bed, remember it's the big match at St Bridget's tomorrow.
| Cut to still of one of us in the uniform as described above.
| SUPERIMPOSED CAPTION: 'THE NAUGHTIEST GIRL IN THE SCHOOL'
Voice Over | Yes, on your screen tomorrow: 'The Naughtiest Girl in the School' starring the men of the 14th Marine Commandos. (cut to a picture made up of inch-square photos of various topical subjects e.g. Stalin, Churchill, Eden, White Home, atom bomb, map of Western Europe, Gandhi) And now it's documentary time, when we look at the momentous last years of the Second World War, and tonight the invasion of Normandy performed by the girls of Oakdene High School, Upper Fifth Science.
| Stock film of amphibious craft brought up on a beach. The front of the craft crashes down and fifty soldiers rush out. We hear schoolgirl voices. Cut to traditional shot thorugh periscope of ocean, cross-sights scanning the hoizon. Submarine-type dramatic noise - motors and asdic. Cut to interior of submarine. A pepperpot looks thorugh the periscope, then looks round at her colleagues.
First Pepperpot | Oh, it's still raining.
| Her four companions continue to knit.
Second Pepperpot | I'm going down the shops.
First Pepperpot | Oh, be a dear and get me some rats' bane for the budgie's boil. Otherwise I'll put your eyes out.
Second Pepperpot | Aye, aye, captain. (goes out)
| Attention noise from the communication tube. A red light flashes by it.
Voice | Coo-ee. Torpedo bay.
First Pepperpot | Yoo-hoo. Torpedo bay.
Third Pepperpot | She said torpedo bay.
First Pepperpot | Yes, she did, she did.
Fourth Pepperpot | Yes, she said torpedo bay. She did, she did.
Voice | Mrs Lieutenant Edale here. Mrs Midshipman Nesbitt's got one of her headaches again, so I put her in the torpedo tube.
First Pepperpot | Roger, Mrs Edale. Stand by to fire Mrs Nesbitt.
All | Stand by to fire Mrs Nesbitt.
First Pepperpot | Red alert, put the kettle on.
Voice | Kettle on.
First Pepperpot | Engine room, stand by to feed the cat.
Voice | Standing by to feed the cat.
First Pepperpot | Fire Mrs Nesbitt.
| ANIMATION: a pepperpot is fired from a torpedo tube through the water, until she travels head first into a battleship with a load clang.
Mrs Nesbitt | Oh, that's much better.
| Cut to a letter as in the last series, plus voice reading it.
Voice Over | As an admiral who came up through the ranks more times than you've had hot dinners, I wish to join my husband Admiral O.W.A Giveaway in condemning this shoddy misrepresentation of our modern navy. The British Navy is one of the finest and most attractive and butchest fighting forces in the world. I love those white flared trousers and the feel of rough blue serge on those pert little buttocks!
| Cut to a man at a desk.
Presenter | I'm afraid we are unable to show you any more of that letter. We continue with a man with a stoat through his head.
| Cut to man with a stoat through his head. He bows. Cut to film of Women's Institute applauding.
Presenter | And now ...
| Cut to a lifeboat somewhere at sea miles from any land. In the lifeboat are five bedraggled sailors, at the end of their tether.
First Sailor | Still no sign of land ... How long is it?
Second Sailor | That's a rather personal question, sir.
First Sailor | You stupid git. I meant how long we've been in the lifeboat. You've spoilt the atmosphere now.
Second Sailor | I'm sorry.
First Sailor | Shut up! We'll have to start again ... Still no sign of land ... how long is it?
Second Sailor | Thirty-three days, sir.
First Sailor | Thirty-three days?
Second Sailor | I don't think we can hold out much longer. I don't think I did spoil the atmosphere.
First Sailor | Shut up!
Second Sailor | I'm sorry, I don't think I did.
First Sailor | Of course you did.
Second Sailor | (to third Sailor) Do you think I spoilt the atmosphere?
Third Sailor | Well, I think you ...
First Sailor | Look, shut up! SHUT UP! ... Still no sign of land ... how long is it?
Second Sailor | Thirty-three days.
Fourth Sailor | Have we started again? (he is kicked on the leg by the first sailor) Wagh!
First Sailor | Still no sign of land ... how long is it?
Second Sailor | Thirty-three days, sir.
First Sailor | Thirty-three days?
Second Sailor | Yes. We can't go hold out much longer, sir. We haven't had any food since the fifth day.
Third Sailor | We're done for, we're done for!
First Sailor | Shut up, Maudling. We've just got to keep hoping someone will find us.
Fourth Sailor | How are you feeling, captain?
Fifth Sailor | Not too good ... I ... feel ... so weak.
Second Sailor | We can't hold out much longer.
Fifth Sailor | Listen ... chaps ... there's one last chance. I'm done for, I've got a gammy leg, I'm going fast, I'll never get through ... but ... some of you might ... so you'd better eat me.
First Sailor | Eat you, sir?
Fifth Sailor | Yes. Eat me.
Second Sailor | Uuuuggghhh! With a gammy leg?
Fifth Sailor | You don't have to eat the leg, Thompson, there's still plenty of good meat ... look at that arm.
Third Sailor | It's not just the leg, sir.
Fifth Sailor | What do you mean?
Third Sailor | Well, sir ... it's just that ...
Fifth Sailor | Why don't you want to eat me?
Third Sailor | I'd rather eat Johnson, sir. (he points at fourth sailor)
Second Sailor | Oh, so would I, sir.
Fifth Sailor | I see.
Fourth Sailor | Well, that's settled then. Everyone eats me.
First Sailor | Well ... I ... er ...
Third Sailor | What, sir?
First Sailor | No, no, you go ahead, I won't ...
Fourth Sailor | Nonsense, nonsense, sir, you're starving. Tuck in!
First Sailor | No, no, it's not just that ...
Second Sailor | What's the matter with Johnson, sir?
First Sailor | Well, he's not kosher.
Third Sailor | That depends how we kill him, sir.
First Sailor | Yes, yes, I see that ... well to be quite frank, I like my meat a little more lean. I'd rather eat Hodges.
Second Sailor | (cheerfully) Oh well ... all right.
Third Sailor | No, I'd still prefer Johnson.
Fifth Sailor | I wish you'd all stop bickering and eat me.
Second Sailor | Look! I'll tell you what. Why don't those of us who want to, eat Johnson, then you, sir, can eat my leg and then we'll make a stock of the Captain and then after that we can eat the rest of Johnson cold for supper.
First Sailor | Good thinking, Hodges.
Fourth Sailor | And we'll finnish off with the peaches. (picks up a tin of peaches)
Third Sailor | And we can start off with the advocados. (picks up a two advocados)
First Sailor | Waitress! (a waitress walks in) We've decided now, we're going to have leg of Hodges ...
| Boos off-screen. Cut to a letter
Voice Over | Dear Sir, I am glad to hear that your studio audience disapproves of the last skit as strongly as I. As a naval officer I abhor the implication that the Royal Navy is a haven for cannibalism. It is well known that we have the problem relatively under control, and that it is the RAF who now suffer the largest casualties in this area. And what do you think the Argylls ate in Aden. Arabs? Yours etc. Captain B.J. Smethwick in a white wine sauce with shallots, mushrooms and garlic.
| ANIMATION: various nasty cannibalistic scenes from Terry Gilliam. Cut to man.
Man | Stop it, stop it. Stop this cannibalism. Let's have a sketch about clean, decent human beings.
| Cut to an undertaker's shop
Undertaker | Morning.
Man | Good Morning.
Undertaker | What can I do for you, squire?
Man | Um, well, I wonder if you can help me. You see, my mother has just died.
Undertaker | Ah well, we can help you. We deal with stiffs.
Man | What?
Undertaker | Well, there's three things we can do with your mum. We can bury her, burn her, or dump her.
Man | Dump her?
Undertaker | Dump her in the Thames.
Man | What?
Undertaker | Oh, did you like her?
Man | Yes!
Undertaker | Oh well, we won't dump her, then. Well, what do you think? We can bury her or burn her.
Man | Well, which do you recommend?
Undertaker | Well, they're both nasty. If we burn her, she gets stuffed in the flames, crackle, crackle, crackle, which is a bit of a shock if she's not quite dead, but quick. (the audience starts booing) and then we give you handful of ashes, which you can pretend are hers.
Man | Oh.
Undertaker | Or, if we bury her she gets eaten up lots of weevils, and nasty maggots, (the booing increases) which as I said before is a bit of a shock if she's not quite dead.
Man | I see. Well, she's definitely dead.
Undertaker | Where is she?
Man | She's in this sack.
Undertaker | Can I have a look? She looks quite young.
Man | Yes, yes, she was.
| Increasing protests from audience
Undertaker | (calling) Fred!
Fred's voice | Yeah?
Undertaker | I think we've got an eater.
Man | What?
| Another undertaker pokes his head round the door
Fred | Right, I'll get the oven on. (goes off)
Man | Er, excuse me, um, are you suggesting eating my mother?
Undertaker | Er ... Yeah. Not raw. Cooked.
Man | What?
Undertaker | Yes, roasted with a few french fries, broccoli, horseradish sauce ...
Man | Well, I do feel a bit peckish.
Voice From Audience | Disgraceful! Boo! (etc.)
Undertaker | Great!
Man | Can we have some parsnips?
Undertaker | (calling) Fred - get some parsnips.
Man | I really don't think I should.
Undertaker | Look, tell you what, we'll eat her, if you feel a bit guilty about it after, we can dig a grave and you can throw up in it.
| A section of the audience rises up in revolt and invades the set, remonstrating with the performers and banging the counter, etc., breaking up the sketch. Zoom away from them and into caption machine; roll credits. The National Anthem starts. The shouting stops. Mix through credits to show audience and everyone on set standing to attention. As the credits end, fade out.